function [] = calcPolVel(numberShot,numberCoil,time,modeNumber)
% (c)GOMTRAIC2013 - Frederik Ostyn
%CALCPOLVEL calculates the poloidal velocity of the tokamak plasma for a
%certain shot number and coil number at time 'time' for a certain mode number. 

close all;

%% Part I : Finding poloidal frequency

%Parameters
windowSize = 1000; %Size of windows (number represents indices of input vector)
maxFreqOfInterest = 100000; %Maximum frequency of interest in Hz

%Getting data
rOI = (time*1e6-floor(windowSize/2)):(time*1e6+floor(windowSize/2)-1); %Range of interest
X = getMirnovDataCoil(numberShot,numberCoil);
XCut = X(rOI);

%Setting hanning window
hanning = hann(windowSize);

%Fast Fourier Transform
XCut= XCut-mean(XCut); %Eliminating off set
for w = 1:windowSize
    XCut(w) = XCut(w)*hanning(w); %Multiplying with Hanning function to make sure boudaries are zero
end
spec = fft(XCut);

%Finding poloidal frequency of 
spec = abs(spec);
fRange = (1:(windowSize/2+1))/windowSize*1e6;
fRangeOfInterest = fRange(1:find(fRange>maxFreqOfInterest,1)); %Getting the interesting part
specOfInterest = spec(1:find(fRange>maxFreqOfInterest,1));
maxi = max(specOfInterest);
maxiInd = find(maxi==specOfInterest,1);
freq = fRangeOfInterest(maxiInd);
freqIsland = freq/modeNumber; %Correction for mode number

%% Part II : Finding radius

%Parameters
a = 0.1; %minor radius [m]
R = 0.4; %major radius [m]
mu0 = 4*pi*1e-7; %vacuum permeability [Vs/Am]

%Getting data
[t,v] = golem_data(numberShot,'toroidal_field');
Bt = v(time*1e6); 
[t1,v1] = golem_data(numberShot,'plasma_current');
Ip = v1(time*1e6);

%Calculating radius
rad = sqrt(2*modeNumber*R*mu0*Ip*(-pi*Bt*a^2+modeNumber*R*mu0*Ip))*a/(modeNumber*R*mu0*Ip);

%% Part III : Finding velocity

velo = 2*pi*rad*freqIsland;

%% Part IV : Display output

display(['Poloidal frequency [Hz]: ' num2str(freqIsland)]);
display(['Radius [m]: ' num2str(rad)]);
display(['Poloidal velocity [m/s] : ' num2str(velo)]);

end